@@ -33,18 +33,27 @@
 #include <locale.h>
 #include <libhildondesktop/libhildondesktop.h>
 #include <libosso.h>
+#include <gconf/gconf-client.h>
+#include <time.h> 
+#include <X11/extensions/Xrender.h>
+#include <gdk/gdkx.h>
+
+#include <X11/Xatom.h>
+/* Gstreamer */
+#include <gst/gst.h>
+#include <gst/interfaces/xoverlay.h>
 
 #define GETTEXT_PACKAGE "livewp"
 #include <glib/gi18n-lib.h>
 
 /* Position of plugin on desktop */
-#define Xstartposition 700 
-#define Ystartposition 448 
+#define Xstartposition 800
+#define Ystartposition 480 
 
 #define THEME_PATH "/usr/share/livewp/theme"
 #define SHORT_TIMER 75 /* 100 milisecond */
 //#define LONG_TIMER 5*60*1000 /* 10 minutes */
-#define LONG_TIMER  20*1000 /* 10 minutes */
+#define LONG_TIMER  20*1000 /* 20 seconds */
 enum { SHORT_TIMER_TYPE, LONG_TIMER_TYPE };
 #define SKY_LEVEL 0 
 #define SUN_LEVEL 0 
@@ -77,6 +86,7 @@ struct _Animation_WallpaperPrivate
     gboolean visible;
     gboolean rich_animation;
     GtkWidget *main_widget;
+    GtkWidget *window;
     GtkWidget *right_corner;
     AWallpaperPlugin *desktop_plugin;
     DBusConnection      *dbus_conn;
@@ -88,6 +98,15 @@ struct _Animation_WallpaperPrivate
     GHashTable * hash_scene_func;
     GKeyFile *config_file;
     gint view;
+    pid_t  pid;
+    pid_t  podpid;
+    guint view_notify;
+    guint alive_timer;
+    time_t last_alive_event;
+    gchar *theme_string_parametr1;
+    guint theme_int_parametr1;
+    GstElement *pipeline;
+    gboolean running;
 };
 
 struct _AWallpaperPlugin
@@ -108,6 +127,25 @@ struct _AWallpaperPluginClass
 #define LIVEWP_SIGNAL_RELOAD_CONFIG_PATH "/org/maemo/livewp/reload_config"
 #define LIVEWP_RELOAD_CONFIG "reload_config"
 #define LIVEWP_RELOAD_PLUGIN "reload_plugin"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW1 "stop_livebg_on_view1"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW2 "stop_livebg_on_view2"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW3 "stop_livebg_on_view3"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW4 "stop_livebg_on_view4"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW1 "pause_livebg_on_view1"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW2 "pause_livebg_on_view2"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW3 "pause_livebg_on_view3"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW4 "pause_livebg_on_view4"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW1 "play_livebg_on_view1"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW2 "play_livebg_on_view2"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW3 "play_livebg_on_view3"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW4 "play_livebg_on_view4"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW1 "alive_livebg_on_view1"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW2 "alive_livebg_on_view2"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW3 "alive_livebg_on_view3"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW4 "alive_livebg_on_view4"
+
+
+
 
 /* For DBUS notification */
 #define NOTIFY_SIGNAL_INTERFACE "org.freedesktop.Notifications"
