@@ -29,6 +29,8 @@
 #include "livewp-scene.h"
 #include <sys/time.h>
 #include <stdlib.h>
+#include <unistd.h>
+#include <sys/wait.h>
 
 #define GCONF_KEY_POSITION "/apps/osso/hildon-desktop/applets/livewp-home-widget.desktop-%i/position"
 #define GCONF_KEY_MODIFIED "/apps/osso/hildon-desktop/applets/livewp-home-widget.desktop-%i/modified"
@@ -44,7 +46,7 @@ lw_applet_realize (GtkWidget *widget)
     GdkScreen *screen;
     gchar * strid; 
     gint id; 
-    AWallpaperPlugin *desktop_plugin = widget;
+    AWallpaperPlugin *desktop_plugin = (AWallpaperPlugin *)widget;
     char* child_argv[] =  {"/usr/bin/livewp", "0", (char *) 0 };
 
 
@@ -72,7 +74,7 @@ lw_applet_realize (GtkWidget *widget)
     	fprintf(stderr,"Problem with new process");
     }
 
-    desktop_plugin_visible_notify(widget, NULL, desktop_plugin);
+    desktop_plugin_visible_notify((GObject *)widget, NULL, desktop_plugin);
 
 #if 0
     /* Load config */
@@ -90,30 +92,6 @@ lw_applet_realize (GtkWidget *widget)
     GTK_WIDGET_CLASS (animation_wallpaper_plugin_parent_class)->realize (widget);
 }
 
-
-static gboolean
-lw_applet_expose_event(GtkWidget      *widget,
-                                        GdkEventExpose *event)
-{
-  cairo_t *cr;
-
-  /* Create cairo context */
-  cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
-  gdk_cairo_region (cr, event->region);
-  cairo_clip (cr);
-
-  /* Draw alpha background */
-  cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-  cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.0);
-  cairo_paint (cr);
-
-  /* Free context */
-  cairo_destroy (cr);
-
-  return GTK_WIDGET_CLASS (animation_wallpaper_plugin_parent_class)->expose_event (widget,
-                                                                                  event);
-}
-
 static gboolean
 expose_event (GtkWidget *widget,GdkEventExpose *event,
      gpointer data)
@@ -212,8 +190,6 @@ void
 create_hildon_actor_text(Actor *actor, AWallpaperPlugin *desktop_plugin) 
 {
   GtkWidget *ha = NULL;
-  GdkPixbuf *pixbuf = NULL;
-  GtkWidget *image = NULL;
   GtkWidget *label = NULL;
 
   ha = hildon_animation_actor_new();
@@ -378,7 +354,7 @@ run_long_timeout(AWallpaperPlugin *desktop_plugin)
 
     if (!desktop_plugin->priv->scene)
 	return;
-    /* fprintf(stderr, "!!!run long timeout short_timer=%d\n", desktop_plugin->priv->short_timer); */
+    /*ifprintf(stderr, "!!!run long timeout short_timer=%d\n", desktop_plugin->priv->short_timer); */
     if (desktop_plugin->priv->scene->daytime != daytime){
         desktop_plugin->priv->scene->daytime = daytime;
         tmp = desktop_plugin->priv->scene->actors;
@@ -420,7 +396,7 @@ long_timeout (AWallpaperPlugin *desktop_plugin)
     GstFormat fmt = GST_FORMAT_TIME;
     gint64 p;
 
-    /* fprintf(stderr, "long_timeout %i\n", desktop_plugin->priv->long_timer); */
+    /*fprintf(stderr, "long_timeout %i\n", desktop_plugin->priv->long_timer); */
     if (desktop_plugin->priv->pipeline){
 	if (!desktop_plugin->priv->visible){
 		gst_element_query_position(desktop_plugin->priv->pipeline, &fmt, &p);
@@ -522,9 +498,6 @@ send_alive_event(Animation_WallpaperPrivate *priv)
 static void
 animation_wallpaper_plugin_init (AWallpaperPlugin *desktop_plugin)
 {
-    GtkWidget *rich_animation;
-    gchar           buffer[2048];
-    gchar str[128];
 
     //fprintf(stderr, "!!!!!!!plugin init \n");
     Animation_WallpaperPrivate *priv =  Animation_Wallpaper_HOME_PLUGIN_GET_PRIVATE (desktop_plugin);
@@ -535,7 +508,7 @@ animation_wallpaper_plugin_init (AWallpaperPlugin *desktop_plugin)
     livewp_initialize_dbus(priv);
 
     priv->desktop_plugin = desktop_plugin;
-    priv->window = desktop_plugin;
+    priv->window = (GtkWidget *)desktop_plugin;
     priv->visible = FALSE;
     priv->short_timer = 0;
     priv->xapplet = 0;
@@ -623,11 +596,8 @@ fprintf(stderr,"lw_applet_finalize\n");
 static void
 desktop_widget_finalize (GObject *object)
 {
-     AWallpaperPlugin *desktop_plugin = Animation_Wallpaper_HOME_PLUGIN (object);
-     Animation_WallpaperPrivate *priv = desktop_plugin->priv;
-     
-       /* Call the base class's implementation: */
-      G_OBJECT_CLASS (animation_wallpaper_plugin_parent_class)->finalize (object);
+      /* Call the base class's implementation: */
+     G_OBJECT_CLASS (animation_wallpaper_plugin_parent_class)->finalize (object);
 }
 
 static void
@@ -641,7 +611,6 @@ animation_wallpaper_plugin_class_init (AWallpaperPluginClass *klass) {
     gobject_class->destroy = (gpointer)lw_applet_finalize;
     object_class->finalize = desktop_widget_finalize;
     widget_class->realize = lw_applet_realize;
-//    widget_class->expose_event = lw_applet_expose_event;
 
     g_type_class_add_private (klass, sizeof (Animation_WallpaperPrivate));
 
