@@ -55,7 +55,7 @@ destroy_scene(AWallpaperPlugin *desktop_plugin)
 void
 reload_scene(AWallpaperPlugin *desktop_plugin)
 {
-    fprintf(stderr,"Reload scene %s\n", desktop_plugin->priv->theme);  
+    /* fprintf(stderr,"Reload scene %s\n", desktop_plugin->priv->theme); */
     destroy_scene(desktop_plugin);
     init_scene_theme(desktop_plugin);
 }
@@ -71,7 +71,7 @@ init_scene_Accel(AWallpaperPlugin *desktop_plugin)
     gint sizes1[4] = {57, 76, 43, 50},
          n, j;
     
-    fprintf(stderr, "init scene accel\n");
+    /* fprintf(stderr, "init scene accel\n"); */
     scene = g_new0(Scene, 1);
     scene->actors = NULL;
     desktop_plugin->priv->scene = scene;
@@ -85,16 +85,16 @@ init_scene_Accel(AWallpaperPlugin *desktop_plugin)
     child = g_ptr_array_sized_new(16);
     
     for (j= 0; j<4; j++){
-    for (n=0; n<4; n++){
-        str = g_strdup_printf("tape%i.png", n+1);
-        actor = init_object(desktop_plugin, "tape", str,
-                            fast_rnd(800), fast_rnd(480), 2+fast_rnd(6), 800, sizes1[n],
-                            TRUE, TRUE, 100, 255,
-                            NULL, NULL, NULL);
-        scene->actors = g_slist_append(scene->actors, actor);
-        g_ptr_array_add(child, actor);
-        g_free(str);
-    }
+        for (n=0; n<4; n++){
+            str = g_strdup_printf("tape%i.png", n+1);
+            actor = init_object(desktop_plugin, "tape", str,
+                                fast_rnd(800), fast_rnd(480), 2+fast_rnd(6), 800, sizes1[n],
+                                TRUE, TRUE, 100, 255,
+                                NULL, NULL, NULL);
+            scene->actors = g_slist_append(scene->actors, actor);
+            g_ptr_array_add(child, actor);
+            g_free(str);
+        }
     }
     actor = init_object(desktop_plugin, "tape", "", 
                       0, 800, 5, 800, 170, 
@@ -192,16 +192,13 @@ init_scene_Xsnow(AWallpaperPlugin *desktop_plugin){
     g_free(run_string);
 }
 /*******************************************************************************/
-gboolean cb_timeout0(AWallpaperPlugin *desktop_plugin) {
-    GstFormat fmt = GST_FORMAT_TIME;
-    gboolean test;
-    gint64 len;
-    gint len_seconds = 0;
+gboolean 
+cb_timeout0(AWallpaperPlugin *desktop_plugin) {
 
     if (!desktop_plugin || !desktop_plugin->priv->pipeline)
         return FALSE;
     if (desktop_plugin->priv->theme_int_parametr1 == 0){
-        if (!gst_element_seek(GST_PIPELINE (desktop_plugin->priv->pipeline), 1.0, GST_FORMAT_TIME,
+        if (!gst_element_seek((GstElement *)GST_PIPELINE (desktop_plugin->priv->pipeline), 1.0, GST_FORMAT_TIME,
                                           GST_SEEK_FLAG_FLUSH, GST_SEEK_TYPE_SET, 
                                           desktop_plugin->priv->theme_int_parametr1 * GST_SECOND,
                                           GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE))
@@ -212,7 +209,7 @@ gboolean cb_timeout0(AWallpaperPlugin *desktop_plugin) {
     if (gst_element_get_state (desktop_plugin->priv->pipeline, NULL, NULL, -1) == GST_STATE_CHANGE_FAILURE) 
         return TRUE;
     else{
-         if (!gst_element_seek(GST_PIPELINE (desktop_plugin->priv->pipeline), 1.0, GST_FORMAT_TIME,
+         if (!gst_element_seek((GstElement *)GST_PIPELINE (desktop_plugin->priv->pipeline), 1.0, GST_FORMAT_TIME,
                                           GST_SEEK_FLAG_FLUSH, GST_SEEK_TYPE_SET, 
                                           desktop_plugin->priv->theme_int_parametr1 * GST_SECOND,
                                           GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE))
@@ -226,7 +223,6 @@ init_scene_Video(AWallpaperPlugin *desktop_plugin)
 {
     GstElement *bin;                                                                                                                                                           
     GstElement *videosink;                                                                                                
-    GstFormat format; 
     gchar *file_plus_uri;
 
 
@@ -240,7 +236,7 @@ init_scene_Video(AWallpaperPlugin *desktop_plugin)
     {
     	GstBus *bus;
      	bus = gst_pipeline_get_bus (GST_PIPELINE (desktop_plugin->priv->pipeline));
-       	gst_bus_add_watch(bus, bus_call, desktop_plugin);
+       	gst_bus_add_watch(bus, (GstBusFunc)bus_call, desktop_plugin);
     	gst_object_unref (bus);
     }
     file_plus_uri = g_strdup_printf("file://%s",desktop_plugin->priv->theme_string_parametr1);
@@ -251,8 +247,8 @@ init_scene_Video(AWallpaperPlugin *desktop_plugin)
 	    gst_x_overlay_set_xwindow_id (GST_X_OVERLAY (videosink), GDK_DRAWABLE_XID(desktop_plugin->priv->window->window));
 
     if (desktop_plugin->priv->visible){
+        g_timeout_add(50, (GSourceFunc)cb_timeout0, desktop_plugin); 
         gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_PLAYING);
-        g_timeout_add(100, cb_timeout0, desktop_plugin); 
     }
    
     //gst_element_get_state(deskddtop_plugin->priv->pipeline, NULL, NULL, 100 * GST_MSECOND);
