@@ -30,7 +30,7 @@
 #include <sys/time.h>
 #include "livewp-rules.h"
 #include <glib-object.h>
-
+#include <unistd.h>
 
 
 void destroy_scene(AWallpaperPlugin *desktop_plugin);
@@ -44,5 +44,6 @@ void init_scene_Accel(AWallpaperPlugin *desktop_plugin);
 void init_scene_Video(AWallpaperPlugin *desktop_plugin);
 void init_scene_Xsnow(AWallpaperPlugin *desktop_plugin);
 void init_scene_theme(AWallpaperPlugin *desktop_plugin);
+void create_hildon_actor_text(Actor *actor, AWallpaperPlugin *desktop_plugin); 
 
 #endif
