@@ -34,7 +34,7 @@ void lw_about(void){
     gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
     gtk_window_set_modal(GTK_WINDOW(window), TRUE);
     vbox = gtk_vbox_new (FALSE, 5);
-    label_about = gtk_label_new (_("Live Wallpaper Version 0.7 \n Copyright(c) 2010\n \
+    label_about = gtk_label_new (_("Live Wallpaper Version 0.7.1 \n Copyright(c) 2010\n \
 Tanya Makova\n Vlad Vasiliev\n \
 Copyright(c) 2010 for design themes Berlin, Modern and Accel Vasya Bobrikov\n \
 Copyright(c) 2010 for design theme Matrix Andrew Zhilin\n \
@@ -133,23 +133,23 @@ changed_value_theme_cb (HildonPickerButton *picker, Animation_WallpaperPrivate *
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(priv->window)->vbox),
                                    vbox, TRUE, TRUE, 5);
     if (choice) {
-        if (!strcmp(choice, "Berlin")){
+        if (!strcmp(choice, _("Berlin"))){
             rich_animation_additional_parametr(vbox,priv);
         }
-        if (!strcmp(choice, "Modern")){
+        if (!strcmp(choice, _("Modern"))){
             rich_animation_additional_parametr(vbox,priv);
         }
-        if (!strcmp(choice, "Matrix")){
+        if (!strcmp(choice, _("Matrix"))){
             rich_animation_additional_parametr(vbox,priv);
         }
-        if (!strcmp(choice, "Xsnow")){
+        if (!strcmp(choice, _("Xsnow"))){
             rich_animation_additional_parametr(vbox,priv);
         }
 
-        if (!strcmp(choice, "Accel")){
+        if (!strcmp(choice, _("Accel"))){
             rich_animation_additional_parametr(vbox,priv);
         }
-        if (!strcmp(choice, "Video")){
+        if (!strcmp(choice, _("Video"))){
             additional_parametr_for_theme_video(vbox, priv);
         }
     }
@@ -417,6 +417,15 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
         case GTK_RESPONSE_YES:
             /* Check theme */
             if (hildon_button_get_value(HILDON_BUTTON (theme_button))){
+                /* Check Xsnow program */
+                if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Xsnow"))){
+                    if (access("/usr/bin/xsnow", F_OK) != 0){
+                        hildon_banner_show_information(GTK_WIDGET(button), NULL, 
+                        _("You haven't got the installed package Xsnow. Please install it via using Application Manager"));
+                        /* if not scuccess exit from wthout saving */ 
+                        break;
+                    }
+                }
 
                 if (priv->theme)
                     g_free(priv->theme);
@@ -431,7 +440,6 @@ lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv) {
                     priv->theme = g_strdup("Accel");
                 if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Xsnow")))
                     priv->theme = g_strdup("Xsnow");
- 
                 if (!strcmp(hildon_button_get_value(HILDON_BUTTON (theme_button)), _("Video"))){
                     priv->theme = g_strdup("Video");
                     button1 = g_object_get_data(G_OBJECT(priv->window), "filename_button");
