@@ -23,6 +23,7 @@
 */
 /*******************************************************************************/
 #include "livewp-common.h"
+#include <hildon-fm-2/hildon/hildon-file-chooser-dialog.h>
 #include <unistd.h>
 void lw_main_settings(Animation_WallpaperPrivate *priv, gpointer data);
 void save_config(Animation_WallpaperPrivate *priv);
@@ -34,4 +35,10 @@ void start_applet(gint number);
 void stop_applet(gint number);
 void send_dbus_signal (Animation_WallpaperPrivate *priv, const gchar *interface,
                   const gchar *path, const gchar *member);
+gint read_config(Animation_WallpaperPrivate *priv);
+void lw_theme_settings(GtkWidget *button, Animation_WallpaperPrivate *priv); 
+void theme_button_clicked(GtkButton *button, Animation_WallpaperPrivate *priv);
+void rich_animation_additional_parametr(GtkWidget *vbox, Animation_WallpaperPrivate *priv);
+void additional_parametr_for_theme_video(GtkWidget *vbox, Animation_WallpaperPrivate *priv);
+
 
